@@ -1,7 +1,7 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 #
 # @package      hubzero-expire-sessions
-# @file         expire-sessions.py
+# @file         expire-sessions
 # @author       Rick Kennell <kennell@purdue.edu>
 # @author	    John Rosheck <jrosheck@purdue.edu>
 # @copyright    Copyright (c) 2005-2011 Purdue University. All rights reserved.
@@ -37,7 +37,7 @@ foreground = 0
 expire_interval = 15
 logfile_name = "/var/log/expire-sessions/expire-sessions.log"
 logfile = None
-pidfile = "/var/run/expire-sessions/expire-sessions.pid"
+pidfile = "/var/run/expire-sessions.pid"
 
 if os.path.exists("/usr/lib/mw/bin/maxwell"):
   mwprog="/usr/lib/mw/bin/maxwell"
@@ -45,7 +45,7 @@ elif os.path.exists("/usr/lib/hubzero/bin/maxwell"):
   mwprog="/usr/lib/hubzero/bin/maxwell"
 elif os.path.exists("/usr/bin/maxwell"):
   mwprog="/usr/bin/maxwell"
-else
+else:
   mwprog=""
 
 if os.path.exists("/etc/mw-www/maxwell.conf"):
@@ -54,7 +54,7 @@ elif os.path.exists("/etc/hubzero/maxwell.conf"):
   config_file="/etc/hubzero/maxwell.conf"
 elif os.path.exists("/etc/mw/maxwell.conf"):
   config_file="/etc/mw/maxwell.conf"
-else
+else:
   config_file=""
 
 #==============================================================================
